@@ -2,6 +2,8 @@ from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker, scoped_session
 
+from wafec.fi.hypothesis.configuration import config
+
 __all__ = [
     "Base",
     "engine",
@@ -10,10 +12,9 @@ __all__ = [
 ]
 
 
-DATABASE_CONNECTION_STRING = 'mysql+pymysql://test:test-321@localhost:3306/fi'
-
+DATABASE_CONNECTION_STRING = config['database']['connection']
 Base = declarative_base()
 engine = create_engine(DATABASE_CONNECTION_STRING)
 session_factory = sessionmaker(bind=engine, autocommit=False, autoflush=False)
 db_session = scoped_session(session_factory)
-Base.query_property = db_session.query_property()
+Base.query_property = db_session.query_property()
\ No newline at end of file
